==> mktcenter-service-2.2.10-20221226.085400-2-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskWXDetailBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.bizvane.appletservice.models.bo.AppletBrandFunctionBo;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @Author: lijunwei
 * @Time: 2018/8/15 11:50
 */
public class TaskWXDetailBO {
    private Long mktTaskId;
    private String taskName ;
    private String taskCode;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date startTime;
  @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date   endTime;
    private  String  taskInfo;
    private Integer points;
    private String shareTitle;
    private String shareImg;
    private Integer taskType;
    private AppletBrandFunctionBo appletBrandFunctionBo;
    private Integer detailShowType;
    private String detailShowImg;

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareImg() {
        return shareImg;
    }

    public void setShareImg(String shareImg) {
        this.shareImg = shareImg;
    }

    List<TaskCouponWXBO>  taskCouponWXBOs;

    public Long getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(Long mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public List<TaskCouponWXBO> getTaskCouponWXBOs() {
        return taskCouponWXBOs;
    }

    public void setTaskCouponWXBOs(List<TaskCouponWXBO> taskCouponWXBOs) {
        this.taskCouponWXBOs = taskCouponWXBOs;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public AppletBrandFunctionBo getAppletBrandFunctionBo() {
        return appletBrandFunctionBo;
    }

    public void setAppletBrandFunctionBo(AppletBrandFunctionBo appletBrandFunctionBo) {
        this.appletBrandFunctionBo = appletBrandFunctionBo;
    }

    public Integer getDetailShowType() {
        return detailShowType;
    }

    public void setDetailShowType(Integer detailShowType) {
        this.detailShowType = detailShowType;
    }

    public String getDetailShowImg() {
        return detailShowImg;
    }

    public void setDetailShowImg(String detailShowImg) {
        this.detailShowImg = detailShowImg;
    }
}

==> mktcenter-service-20241220-20241210.064205-1-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskWXDetailBO.java <==
package com.bizvane.mktcenterservice.models.bo;

import com.bizvane.appletservice.models.bo.AppletBrandFunctionBo;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @Author: lijunwei
 * @Time: 2018/8/15 11:50
 */
public class TaskWXDetailBO {
    private Long mktTaskId;
    private String taskName ;
    private String taskCode;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date startTime;
  @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date   endTime;
    /**
     * 任务描述显示类型 0-文本内容 1-自定义图片 2-富文本
     */
    private Integer taskInfoType;
    private  String  taskInfo;
    private Integer points;
    private String shareTitle;
    private String shareImg;
    private Integer taskType;
    private AppletBrandFunctionBo appletBrandFunctionBo;
    private Integer detailShowType;
    private String detailShowImg;
    private Integer  rewarded;  // 1=已完成  0未完成
    private String templateCode;
    private String templateJson;

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareImg() {
        return shareImg;
    }

    public void setShareImg(String shareImg) {
        this.shareImg = shareImg;
    }

    List<TaskCouponWXBO>  taskCouponWXBOs;

    public Long getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(Long mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getTaskInfoType() {
        return taskInfoType;
    }

    public void setTaskInfoType(Integer taskInfoType) {
        this.taskInfoType = taskInfoType;
    }

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public List<TaskCouponWXBO> getTaskCouponWXBOs() {
        return taskCouponWXBOs;
    }

    public void setTaskCouponWXBOs(List<TaskCouponWXBO> taskCouponWXBOs) {
        this.taskCouponWXBOs = taskCouponWXBOs;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public AppletBrandFunctionBo getAppletBrandFunctionBo() {
        return appletBrandFunctionBo;
    }

    public void setAppletBrandFunctionBo(AppletBrandFunctionBo appletBrandFunctionBo) {
        this.appletBrandFunctionBo = appletBrandFunctionBo;
    }

    public Integer getDetailShowType() {
        return detailShowType;
    }

    public void setDetailShowType(Integer detailShowType) {
        this.detailShowType = detailShowType;
    }

    public String getDetailShowImg() {
        return detailShowImg;
    }

    public void setDetailShowImg(String detailShowImg) {
        this.detailShowImg = detailShowImg;
    }

    public Integer getRewarded() {
        return rewarded;
    }

    public void setRewarded(Integer rewarded) {
        this.rewarded = rewarded;
    }

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public String getTemplateJson() {
        return templateJson;
    }

    public void setTemplateJson(String templateJson) {
        this.templateJson = templateJson;
    }
}
